@@ -51,7 +51,8 @@ class Company(IngestedDataType):
 
         pdl_domain_name = pdl_input.get('website')
         pdl_company_type = pdl_input.get('type')
-        pdl_company_size_range_split = pdl_input.get('size').split('-')
+        pdl_company_size = pdl_input.get('size')
+        pdl_company_size_range_split = pdl_company_size.split('-') if pdl_company_size else None
         pdl_location = pdl_input.get('location')
 
         return Company(
@@ -71,14 +72,15 @@ class Company(IngestedDataType):
             linkedin_url=pdl_input.get('linkedin_url'),
             industry=pdl_input.get('industry'),  # should this be canonical?
             categories=pdl_input.get('tags'),
-            company_type=CompanyType(convert_pdl_company_type_to_company_type(PDLCompanyType[pdl_company_type])),
+            company_type=CompanyType(convert_pdl_company_type_to_company_type(PDLCompanyType[pdl_company_type]))
+            if pdl_company_type else None,
             company_size_range=CompanySizeRange(
                 int(pdl_company_size_range_split[0]),
                 int(pdl_company_size_range_split[1])
-            ),
+            ) if pdl_company_size_range_split and len(pdl_company_size_range_split) == 2 else None,
             company_size_on_linkedin=pdl_input.get('employee_count'),
             founded_year=pdl_input.get('founded'),
-            hq=Location.from_pdl(pdl_location),
-            locations=[Location.from_pdl(pdl_location)],
+            hq=Location.from_pdl(pdl_location) if pdl_location else None,
+            locations=[Location.from_pdl(pdl_location)] if pdl_location else None,
             last_enriched_at=get_current_datetime_aws_format()
         )
